# $File: //depot/OurNet-BBS/BBS/MELIX/UserGroup.pm $ $Author: autrijus $
# $Revision: #5 $ $Change: 2440 $ $DateTime: 2001/11/27 15:38:54 $

package OurNet::BBS::MELIX::UserGroup;

use base qw/OurNet::BBS::MAPLE3::UserGroup/;
use fields qw/_ego _hash _array/;

use OurNet::BBS::Base;

1;
